ntrfc.math package
==================

Submodules
----------

ntrfc.math.methods module
-------------------------

.. automodule:: ntrfc.math.methods
   :members:
   :undoc-members:
   :show-inheritance:

ntrfc.math.vectorcalc module
----------------------------

.. automodule:: ntrfc.math.vectorcalc
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ntrfc.math
   :members:
   :undoc-members:
   :show-inheritance:
